==> user-service-local-2.2.0.13-Release-sources.jar: com/bizunited/platform/user/service/local/configuration/UserLocalServiceAutoConfiguration.java <==
package com.bizunited.platform.user.service.local.configuration;

import com.bizunited.platform.user.common.service.UserExtentFieldService;
import com.bizunited.platform.user.common.service.organization.OrganizationService;
import com.bizunited.platform.user.common.service.position.PositionService;
import com.bizunited.platform.user.common.service.user.UserService;
import com.bizunited.platform.user.common.service.userGroup.UserGroupService;
import com.bizunited.platform.user.service.local.service.internal.OrganizationServiceImpl;
import com.bizunited.platform.user.service.local.service.internal.PositionServiceImpl;
import com.bizunited.platform.user.service.local.service.internal.UserExtentFieldServiceImpl;
import com.bizunited.platform.user.service.local.service.internal.UserGroupServiceImpl;
import com.bizunited.platform.user.service.local.service.internal.UserServiceImpl;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.domain.EntityScan;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.jpa.repository.config.EnableJpaRepositories;

/**
 * 用户身份中心的本地实现自动化配置
 * @Author: Paul Chan
 * @Date: 2020-03-16 10:14
 */
@Configuration
@EntityScan(basePackages = "com.bizunited.platform.user.service.local.entity")
@EnableJpaRepositories(basePackages = "com.bizunited.platform.user.service.local.repository")
@ComponentScan(basePackages = {"com.bizunited.platform.user", "com.bizunited.platform.common"})
public class UserLocalServiceAutoConfiguration {

  @Bean(name="OrganizationService")
  @ConditionalOnMissingBean
  public OrganizationService getOrganizationService() {
    return new OrganizationServiceImpl();
  }
  @Bean(name="PositionService")
  @ConditionalOnMissingBean
  public PositionService getPositionService() {
    return new PositionServiceImpl();
  }
  @Bean(name="UserGroupService")
  @ConditionalOnMissingBean
  public UserGroupService getUserGroupService() {
    return new UserGroupServiceImpl();
  }
  @Bean(name="UserService")
  @ConditionalOnMissingBean
  public UserService getUserService() {
    return new UserServiceImpl();
  }
  @Bean(name="UserExtentFieldService")
  @ConditionalOnMissingBean
  public UserExtentFieldService getUserExtentFieldService() {
    return new UserExtentFieldServiceImpl();
  }
}

==> user-service-local-2.2.1.18-Release-sources.jar: com/bizunited/platform/user/service/local/configuration/UserLocalServiceAutoConfiguration.java <==
package com.bizunited.platform.user.service.local.configuration;

import com.bizunited.platform.user.common.service.UserExtentFieldService;
import com.bizunited.platform.user.common.service.organization.OrganizationService;
import com.bizunited.platform.user.common.service.position.PositionService;
import com.bizunited.platform.user.common.service.region.AdministrativeRegionService;
import com.bizunited.platform.user.common.service.user.UserService;
import com.bizunited.platform.user.common.service.userGroup.UserGroupService;
import com.bizunited.platform.user.service.local.service.internal.AdministrativeRegionServiceImpl;
import com.bizunited.platform.user.service.local.service.internal.OrganizationServiceImpl;
import com.bizunited.platform.user.service.local.service.internal.PositionServiceImpl;
import com.bizunited.platform.user.service.local.service.internal.UserExtentFieldServiceImpl;
import com.bizunited.platform.user.service.local.service.internal.UserGroupServiceImpl;
import com.bizunited.platform.user.service.local.service.internal.UserServiceImpl;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.domain.EntityScan;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.data.jpa.repository.config.EnableJpaRepositories;

/**
 * 用户身份中心的本地实现自动化配置
 * @Author: Paul Chan
 * @Date: 2020-03-16 10:14
 */
@Configuration
@EntityScan(basePackages = "com.bizunited.platform.user.service.local.entity")
@EnableJpaRepositories(basePackages = "com.bizunited.platform.user.service.local.repository")
@ComponentScan(basePackages = {"com.bizunited.platform.user", "com.bizunited.platform.common"})
public class UserLocalServiceAutoConfiguration {

  @Bean(name="OrganizationService")
  @ConditionalOnMissingBean
  public OrganizationService getOrganizationService() {
    return new OrganizationServiceImpl();
  }
  @Bean(name="PositionService")
  @ConditionalOnMissingBean
  public PositionService getPositionService() {
    return new PositionServiceImpl();
  }
  @Bean(name="UserGroupService")
  @ConditionalOnMissingBean
  public UserGroupService getUserGroupService() {
    return new UserGroupServiceImpl();
  }
  @Bean(name="UserService")
  @ConditionalOnMissingBean
  public UserService getUserService() {
    return new UserServiceImpl();
  }
  @Bean(name="UserExtentFieldService")
  @ConditionalOnMissingBean
  public UserExtentFieldService getUserExtentFieldService() {
    return new UserExtentFieldServiceImpl();
  }

  @ConditionalOnMissingBean
  @Bean(name = "AdministrativeRegionService")
  public AdministrativeRegionService getAdministrativeRegionService() {
    return new AdministrativeRegionServiceImpl();
  }

}
